@@ -10,7 +10,7 @@ def send_contact_form_email(sender, request, form, **kwargs):
     t = loader.get_template('cccontact/message.txt')
     c = Context({
         'email': data.get('email'),
-        'name': data.get('name')})
+        'name': data.get('name'),
         'message': data.get('m'),
         'phone': data.get('phone')})
     message = t.render(c)
